import {Component, OnDestroy, OnInit, ViewChild} from '@angular/core';
import {DataSourceService} from '../services/data-source.service';
import {Subscription} from 'rxjs';
import {DataCard} from 'facade-api';
import {NgForm} from '@angular/forms';

@Component({
  selector: 'app-patient-information',
  templateUrl: './patient-information.component.html',
  styleUrls: ['./patient-information.component.scss']
})
export class PatientInformationComponent implements OnInit, OnDestroy {
  @ViewChild('form', {static: true}) form: NgForm | undefined;
  public dataCard: DataCard | undefined;
  private homeId = '';
  private repositoryId = '';
  private documentUniqueId = '';
  private version = '';
  private subscription: Subscription | undefined;
  public disableSaveButton = false;

  constructor(private dataSourceService: DataSourceService) {
  }

  ngOnInit(): void {
    this.subscription = this.dataSourceService.dummyDataCards$
      .subscribe((cards) => {
        const {documentUniqueId, version, episodeOfCareIdentifier, ...dataCard} = cards[0];
        this.dataCard = dataCard;
        this.documentUniqueId = documentUniqueId;
        this.version = version;
      });
  }

  ngOnDestroy(): void {
    this.subscription?.unsubscribe();
  }

  public displayRelation(relation: string): string {
    switch (relation) {
      case 'uspec_paaroerende':
        return 'Ukendt';
      case 'ingen_relationer':
        return 'Ingen relation';
      case 'barn':
        return 'Barn';
      case 'mor':
        return 'Mor';
      case 'far':
        return 'Far';
      case 'forælder':
        return 'Forælder';
      case 'søskende':
        return 'Søskende';
      case 'aegtefaelle':
        return 'Ægtefælle';
      case 'barnebarn':
        return 'Barnebarn';
      case 'svigerbarn':
        return 'Svigerbarn';
      case 'øvrig_familie':
        return 'Øvrig familie';
      case 'nabo':
        return 'Nabo';
      case 'samboende':
        return 'Samboende';
      case 'registreret_partner':
        return 'Registreret partner';
      case 'anden':
        return 'Anden';
      case 'søn':
        return 'Søn';
      case 'datter':
        return 'Datter';
      default:
        return '?';
    }
  }

  public save(): void {
    this.disableSaveButton = true;
    this.dataSourceService.updateDataCard(
      this.documentUniqueId,
      this.version,
      this.dataCard as DataCard)
      .subscribe(() => {
        this.disableSaveButton = false;
        this.dataSourceService.refresh();
      });
  }
}
