import {Component, OnInit, ViewChild} from '@angular/core';
import {DataCard} from 'facade-api';
import {DataSourceService} from '../services/data-source.service';
import {NgForm} from '@angular/forms';
import {FormComponent} from '../confirm-navigation-if-dirty.framework';
import {finalize} from 'rxjs/operators';

@Component({
  selector: 'app-pregnancy',
  templateUrl: './pregnancy.component.html',
  styleUrls: ['./pregnancy.component.scss']
})
export class PregnancyComponent extends FormComponent implements OnInit {
  public dataCard: DataCard | undefined;
  public disableSaveButton = false;
  @ViewChild('form', {static: true}) form: NgForm|undefined;
  private documentUniqueId = '';
  private version = '';


  constructor(private dataSourceService: DataSourceService) { super(); }

  ngOnInit(): void {
    this.dataSourceService.dummyDataCards$.subscribe((cards) => {
      const {documentUniqueId, version, episodeOfCareIdentifier, ...dataCard} = cards[0];
      this.dataCard = dataCard;
      this.documentUniqueId = documentUniqueId;
      this.version = version;
      if (!this.dataCard.birthPlaceSection) {
        this.dataCard.birthPlaceSection = {
          dirty: false,
          revisedPlannedBirthPlace: {} as any,
          primaryPlannedBirthPlace: {} as any
        };
      }
      else if (!this.dataCard.birthPlaceSection?.revisedPlannedBirthPlace) {
        this.dataCard.birthPlaceSection.revisedPlannedBirthPlace = {} as any;
      }
    });
  }

  public save(): void {
    if (this.form?.valid) {
      this.disableSaveButton = true;
      this.dataSourceService.updateDataCard(this.documentUniqueId, this.version, this.dataCard as DataCard)
        .pipe(finalize(() => this.disableSaveButton = false))
        .subscribe(() => {
          this.dataSourceService.refresh();
        });
    }
  }

}
